@@ -20,6 +20,9 @@
 #ifndef APPDATA_H
 #define APPDATA_H
 
+/* this define will enable preliminary API 0.6 support */
+#define API06
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -113,12 +116,12 @@ typedef struct appdata_s {
   } dialog_again;
 
   struct {
-    char *import_path;
     GtkWidget *menu_track;
     GtkWidget *menu_item_import;
     GtkWidget *menu_item_export;
     GtkWidget *menu_item_clear;
-    GtkWidget *menu_item_gps;
+    GtkWidget *menu_item_enable_gps;
+    GtkWidget *menu_item_follow_gps;
     struct track_s *track;
     guint handler_id;
     canvas_item_t *gps_item;      // the purple curcle
@@ -172,5 +175,6 @@ typedef struct appdata_s {
 #include "style.h"
 #include "net_io.h"
 #include "banner.h"
+#include "list.h"
 
 #endif // APPDATA_H
